Plugin: JS9Preferences

### JS9 User Preferences

The JS9 preferences plugin allows you to set JS9 user preferences for JS9-enabled Web pages in the current domain. By and large, these are the same preferences that can be found in the JS9 site preferences file (js9Prefs.json), and of course you can set defaults in that file. However, the preferences plugin allows you to set these preferences in cases where you do not have access to this file, e.g. public sites such as js9.si.edu.

Due to cross-browser security limitations, preferences are browser-specific: your Firefox preferences will be maintained separately from your Chrome and Safari preferences.

The following types of user preferences can be set:

- images: colormap, contrast, scale, etc. for all newly displayed images
- regions: region parameters (radius, width, height, etc) for all newly created regions
- fits: a list of binary table extensions to look for in a drag/drop operation, size of image to extract
- displays: settings applied to each JS9 display, these currently consist of mouse/touch actions (see the Mouse Touch plugin for more info)

You can apply your preference choices to the current session using the Apply button. To apply and save these preferences for future sessions, use the Save button. The Show Saved and Delete Saved buttons allow you to view and clear the currently saved values, respectively.